@@ -9,7 +9,7 @@ use JSON::PP qw( encode_json );
 use Encode qw( encode_utf8 );
 
 # ABSTRACT: Dist::Zilla initialization tasks for Plicease
-our $VERSION = '1.94'; # VERSION
+our $VERSION = '1.95'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterMint';
@@ -78,6 +78,7 @@ sub gather_files
   $self->gather_file_gitignore($arg);
   $self->gather_file_gitattributes($arg);
   $self->gather_file_travis_yml($arg);
+  $self->gather_file_appveyor_yml($arg);
 }
 
 sub gather_file_travis_yml
@@ -106,6 +107,41 @@ sub gather_file_travis_yml
 
 }
 
+sub gather_file_appveyor_yml
+{
+  my($self, $arg)  =@_;
+  
+  my $file = Dist::Zilla::File::InMemory->new({
+    name    => '.appveyor.yml',
+    content => join("\n",
+      q{install:},
+      q{  - choco install strawberryperl},
+      q{  - perl -v},
+      q{  - SET PATH=C:\\strawberry\\c\\bin;C:\\strawberry\\perl\\site\\bin;C:\\strawberry\\perl\\bin;%PATH%},
+      q{  - if not exist C:\\Perl5 mkdir C:\\Perl5},
+      q{  - SET PERL5LIB=C:/Perl5/lib/perl5},
+      q{  - SET PERL_LOCAL_LIB_ROOT=C:/Perl5},
+      q{  - SET PERL_MB_OPT=--install_base C:/Perl5},
+      q{  - SET PERL_MM_OPT=INSTALL_BASE=C:/Perl5},
+      q{  - cpanm -n Dist::Zilla},
+      q{  - cpanm - dzil authordeps --missing | cpanm -n},
+      q{  - dzil listdeps --missing | cpanm -n},
+      q{},
+      q{build: off},
+      q{},
+      q{test_script:},
+      q{  - dzil test -v},
+      q{},
+      q{cache:},
+      q{  - C:\\Perl5},
+      q{},
+      q{shallow_clone: true},
+    ),
+  });
+  
+  $self->add_file($file); 
+}
+
 sub gather_file_dist_ini
 {
   my($self, $arg) = @_;
@@ -318,7 +354,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 1.94
+version 1.95
 
 =head1 DESCRIPTION
 
