@@ -4,7 +4,7 @@ use 5.008001;
 use Moose;
 
 # ABSTRACT: add a travis status button to the README.md file
-our $VERSION = '1.94'; # VERSION
+our $VERSION = '1.95'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterBuild';
@@ -18,6 +18,11 @@ has travis_user => (
   default => 'plicease',
 );
 
+has appveyor => (
+  is  => 'ro',
+  isa => 'Str',
+);
+
 sub after_build
 {
   my($self) = @_;
@@ -26,7 +31,11 @@ sub after_build
   {
     my $name = $self->zilla->root->absolute->basename;
     my $user = $self->travis_user;
-    my $status = $self->travis_status ? " [![Build Status](https://secure.travis-ci.org/$user/$name.png)](http://travis-ci.org/$user/$name)" : "";
+    
+    my $status = '';
+    $status .= " [![Build Status](https://secure.travis-ci.org/$user/$name.png)](http://travis-ci.org/$user/$name)" if $self->travis_status;
+    $status .= " [![Build status](https://ci.appveyor.com/api/projects/status/@{[ $self->appveyor ]}/branch/master?svg=true)](https://ci.appveyor.com/project/$user/$name/branch/master)" if $self->appveyor;
+    
     my $content = $readme->slurp;
     $content =~ s{# NAME\s+(.*?) - (.*?#)}{# $1$status\n\n$2}s;
     $content =~ s{# VERSION\s+version (\d+\.|)\d+\.\d+(\\_\d+|)\s+#}{#};
@@ -54,7 +63,7 @@ Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup - add a travis status but
 
 =head1 VERSION
 
-version 1.94
+version 1.95
 
 =head1 SYNOPSIS
 
