@@ -10,7 +10,7 @@ use Term::ANSIColor ();
 use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.94'; # VERSION
+our $VERSION = '1.95'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -191,6 +191,7 @@ sub configure
   $self->add_plugins([
     'Author::Plicease::MarkDownCleanup' => {
             travis_status => int(defined $self->payload->{travis_status} ? $self->payload->{travis_status} : 0),
+      maybe appveyor      => $self->payload->{appveyor},
       maybe travis_user   => $self->payload->{github_user},
     },
   ]);
@@ -281,7 +282,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.94
+version 1.95
 
 =head1 SYNOPSIS
 
@@ -451,6 +452,10 @@ if C<release_tests> is true.
 
 if set to true, then include a link to the travis build page in the readme.
 
+=head2 appveyor
+
+if set to a appveyor id, then include a link to the appveyor build page in the readme.
+
 =head2 mb_class
 
 if builder = ModuleBuild, this is the mb_class passed into the [ModuleBuild]
